==> kibana-7.2.0-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/core_plugins/metrics/public/lib/check_ui_restrictions.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { get } from 'lodash';

export const DEFAULT_UI_RESTRICTION = {
  '*': true,
};

const RESTRICTION_TYPES = {
  WHITE_LISTED_GROUP_BY_FIELDS: 'whiteListedGroupByFields',
  WHITE_LISTER_METRICS: 'whiteListedMetrics',
};

const checkUIRestrictions = (key, restrictions = DEFAULT_UI_RESTRICTION, type) => {
  const isAllEnabled = get(restrictions, `${type}.*`, true);

  return isAllEnabled || get(restrictions, type, {})[key];
};

export const isMetricEnabled = (key, restrictions) => {
  return checkUIRestrictions(key, restrictions, RESTRICTION_TYPES.WHITE_LISTER_METRICS);
};

export const isFieldEnabled = (field, metricType, restrictions = DEFAULT_UI_RESTRICTION) => {
  if (isMetricEnabled(metricType, restrictions)) {
    return checkUIRestrictions(field, restrictions[RESTRICTION_TYPES.WHITE_LISTER_METRICS], metricType);
  }
  return false;
};

export const isGroupByFieldsEnabled = (key, restrictions) => {
  return checkUIRestrictions(key, restrictions, RESTRICTION_TYPES.WHITE_LISTED_GROUP_BY_FIELDS);
};

==> kibana-7.3.1-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/core_plugins/metrics/public/lib/check_ui_restrictions.js <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { get } from 'lodash';

export const DEFAULT_UI_RESTRICTION = {
  '*': true,
};

const RESTRICTION_TYPES = {
  WHITE_LISTED_GROUP_BY_FIELDS: 'whiteListedGroupByFields',
  WHITE_LISTER_METRICS: 'whiteListedMetrics',
};

const checkUIRestrictions = (key, restrictions = DEFAULT_UI_RESTRICTION, type) => {
  const isAllEnabled = get(restrictions, `${type}.*`, true);

  return isAllEnabled || get(restrictions, type, {})[key];
};

export const isMetricEnabled = (key, restrictions) => {
  return checkUIRestrictions(key, restrictions, RESTRICTION_TYPES.WHITE_LISTER_METRICS);
};

export const isFieldEnabled = (field, metricType, restrictions = DEFAULT_UI_RESTRICTION) => {
  if (isMetricEnabled(metricType, restrictions)) {
    return checkUIRestrictions(
      field,
      restrictions[RESTRICTION_TYPES.WHITE_LISTER_METRICS],
      metricType
    );
  }
  return false;
};

export const isGroupByFieldsEnabled = (key, restrictions) => {
  return checkUIRestrictions(key, restrictions, RESTRICTION_TYPES.WHITE_LISTED_GROUP_BY_FIELDS);
};
